@@ -138,6 +138,9 @@ show_help(bool
 
   fprintf(handle,
 "Options:\n"
+#ifndef BUILD_GUI
+"      --debug                print debugging information\n"
+#endif
 "  -f, --latin-fallback       set fallback script to latin\n"
 "  -G, --hinting-limit=N      switch off hinting above this PPEM value\n"
 "                             (default: %d); value 0 means no limit\n"
@@ -158,6 +161,11 @@ show_help(bool
 "  -s, --symbol               input is symbol font\n"
 "  -v, --verbose              show progress information\n"
 "  -V, --version              print version information and exit\n"
+"  -w, --strong-stem-width=S  use strong stem width routine for modes S,\n"
+"                             where S is a string of up to three letters\n"
+"                             with possible values `g' for grayscale,\n"
+"                             `G' for GDI ClearType, and `D' for\n"
+"                             DirectWrite ClearType (default: G)\n"
 "  -x, --increase-x-height=N  increase x height for sizes in the range\n"
 "                             6<=PPEM<=N; value 0 switches off this feature\n"
 "                             (default: %d)\n"
@@ -283,6 +291,10 @@ main(int argc,
   bool have_hinting_limit = false;
   bool have_increase_x_height = false;
 
+  bool gray_strong_stem_width = false;
+  bool gdi_cleartype_strong_stem_width = true;
+  bool dw_cleartype_strong_stem_width = false;
+
   bool ignore_restrictions = false;
   bool pre_hinting = false;
   bool no_info = false;
@@ -290,6 +302,8 @@ main(int argc,
   bool symbol = false;
 
 #ifndef BUILD_GUI
+  bool debug = false;
+
   TA_Progress_Func progress_func = NULL;
   TA_Info_Func info_func = info;
 #endif
@@ -308,7 +322,8 @@ main(int argc,
     enum
     {
       PASS_THROUGH = CHAR_MAX + 1,
-      HELP_ALL_OPTION
+      HELP_ALL_OPTION,
+      DEBUG_OPTION
     };
 
     static struct option long_options[] =
@@ -319,6 +334,9 @@ main(int argc,
 #endif
 
       // ttfautohint options
+#ifndef BUILD_GUI
+      {"debug", no_argument, NULL, DEBUG_OPTION},
+#endif
       {"hinting-limit", required_argument, NULL, 'G'},
       {"hinting-range-max", required_argument, NULL, 'r'},
       {"hinting-range-min", required_argument, NULL, 'l'},
@@ -327,6 +345,7 @@ main(int argc,
       {"latin-fallback", no_argument, NULL, 'f'},
       {"no-info", no_argument, NULL, 'n'},
       {"pre-hinting", no_argument, NULL, 'p'},
+      {"strong-stem-width", required_argument, NULL, 'w'},
       {"symbol", no_argument, NULL, 's'},
       {"verbose", no_argument, NULL, 'v'},
       {"version", no_argument, NULL, 'V'},
@@ -362,7 +381,7 @@ main(int argc,
     };
 
     int option_index;
-    int c = getopt_long_only(argc, argv, "fG:hil:npr:stVvx:X:",
+    int c = getopt_long_only(argc, argv, "fG:hil:npr:stVvx:X:w:",
                              long_options, &option_index);
     if (c == -1)
       break;
@@ -422,6 +441,12 @@ main(int argc,
 #endif
       break;
 
+    case 'w':
+      gray_strong_stem_width = strchr(optarg, 'g') ? true : false;
+      gdi_cleartype_strong_stem_width = strchr(optarg, 'G') ? true : false;
+      dw_cleartype_strong_stem_width = strchr(optarg, 'D') ? true : false;
+      break;
+
     case 'x':
       increase_x_height = atoi(optarg);
       have_increase_x_height = true;
@@ -433,11 +458,19 @@ main(int argc,
 #endif
       break;
 
+#ifndef BUILD_GUI
+    case DEBUG_OPTION:
+      debug = true;
+      break;
+#endif
+
+#ifdef BUILD_GUI
     case HELP_ALL_OPTION:
 #ifdef CONSOLE_OUTPUT
       show_help(true, false);
 #endif
       break;
+#endif
 
     case PASS_THROUGH:
       {
@@ -537,6 +570,10 @@ main(int argc,
     info_data.hinting_range_max = hinting_range_max;
     info_data.hinting_limit = hinting_limit;
 
+    info_data.gray_strong_stem_width = gray_strong_stem_width;
+    info_data.gdi_cleartype_strong_stem_width = gdi_cleartype_strong_stem_width;
+    info_data.dw_cleartype_strong_stem_width = dw_cleartype_strong_stem_width;
+
     info_data.pre_hinting = pre_hinting;
     info_data.increase_x_height = increase_x_height;
     info_data.latin_fallback = latin_fallback;
@@ -548,18 +585,24 @@ main(int argc,
   TA_Error error =
     TTF_autohint("in-file, out-file,"
                  "hinting-range-min, hinting-range-max, hinting-limit,"
+                 "gray-strong-stem-width, gdi-cleartype-strong-stem-width,"
+                 "dw-cleartype-strong-stem-width,"
                  "error-string,"
                  "progress-callback, progress-callback-data,"
                  "info-callback, info-callback-data,"
                  "ignore-restrictions, pre-hinting, increase-x-height,"
-                 "fallback-script, symbol",
+                 "fallback-script, symbol,"
+                 "debug",
                  in, out,
                  hinting_range_min, hinting_range_max, hinting_limit,
+                 gray_strong_stem_width, gdi_cleartype_strong_stem_width,
+                 dw_cleartype_strong_stem_width,
                  &error_string,
                  progress_func, &progress_data,
                  info_func, &info_data,
                  ignore_restrictions, pre_hinting, increase_x_height,
-                 latin_fallback, symbol);
+                 latin_fallback, symbol,
+                 debug);
 
   if (error)
   {
@@ -585,6 +628,9 @@ main(int argc,
     else if (error == TA_Err_Missing_Unicode_CMap)
       fprintf(stderr,
               "No Unicode character map.\n");
+    else if (error == TA_Err_Missing_Symbol_CMap)
+      fprintf(stderr,
+              "No symbol character map.\n");
     else if (error == TA_Err_Missing_Glyph)
       fprintf(stderr,
               "No glyph for the key character"
@@ -620,6 +666,8 @@ main(int argc,
   app.setOrganizationDomain("freetype.org");
 
   Main_GUI gui(hinting_range_min, hinting_range_max, hinting_limit,
+               gray_strong_stem_width, gdi_cleartype_strong_stem_width,
+               dw_cleartype_strong_stem_width,
                increase_x_height, ignore_restrictions, pre_hinting,
                no_info, latin_fallback, symbol);
   gui.show();
