@@ -27,11 +27,11 @@
 #define ADDITIONAL_STACK_ELEMENTS 20
 
 
-/* #define DEBUGGING */
+#define DEBUGGING
 
 
 #ifdef TA_DEBUG
-int _ta_debug = 1;
+int _ta_debug = 0;
 int _ta_debug_disable_horz_hints;
 int _ta_debug_disable_vert_hints;
 int _ta_debug_disable_blue_hints;
@@ -1658,10 +1658,10 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
 
   TA_GlyphHints hints;
 
-  FT_UInt num_action_hints_records;
-  FT_UInt num_point_hints_records;
-  Hints_Record* action_hints_records;
-  Hints_Record* point_hints_records;
+  FT_UInt num_action_hints_records = 0;
+  FT_UInt num_point_hints_records = 0;
+  Hints_Record* action_hints_records = NULL;
+  Hints_Record* point_hints_records = NULL;
 
   Recorder recorder;
   FT_UInt num_stack_elements;
@@ -1672,6 +1672,10 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
 
   FT_Byte* pos[3];
 
+#ifdef TA_DEBUG
+  int _ta_debug_save;
+#endif
+
 
   /* XXX: right now, we abuse this flag to control */
   /*      the global behaviour of the auto-hinter */
@@ -1689,8 +1693,20 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
   if (error)
     return error;
 
+#ifdef TA_DEBUG
+  /* temporarily disable debugging output */
+  /* to avoid getting the information twice */
+  _ta_debug_save = _ta_debug;
+  _ta_debug = 0;
+#endif
+
   ta_loader_register_hints_recorder(font->loader, NULL, NULL);
   error = ta_loader_load_glyph(font->loader, face, (FT_UInt)idx, load_flags);
+
+#ifdef TA_DEBUG
+  _ta_debug = _ta_debug_save;
+#endif
+
   if (error)
     return error;
 
@@ -1754,12 +1770,19 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
   /* to find hints records which get pushed onto the bytecode stack */
 
 #ifdef DEBUGGING
+  if (font->debug)
   {
     int num_chars, i;
+    char buf[256];
 
 
-    num_chars = fprintf(stderr, "glyph %ld\n", idx);
-    for (i = 0; i < num_chars - 1; i++)
+    (void)FT_Get_Glyph_Name(face, idx, buf, 256);
+
+    num_chars = fprintf(stderr, "glyph %ld", idx);
+    if (*buf)
+      num_chars += fprintf(stderr, " (%s)", buf);
+    fprintf(stderr, "\n");
+    for (i = 0; i < num_chars; i++)
       putc('=', stderr);
     fprintf(stderr, "\n\n");
 
@@ -1771,11 +1794,6 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
                                     TA_hints_recorder,
                                     (void*)&recorder);
 
-  num_action_hints_records = 0;
-  num_point_hints_records = 0;
-  action_hints_records = NULL;
-  point_hints_records = NULL;
-
   for (size = font->hinting_range_min;
        size <= font->hinting_range_max;
        size++)
@@ -1803,18 +1821,31 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
                                      ins_buf, recorder.hints_record.buf))
     {
 #ifdef DEBUGGING
+      if (font->debug)
       {
+        int num_chars, i;
+
+
         have_dumps = 1;
 
-        fprintf(stderr, "  size %d:\n", size);
+        num_chars = fprintf(stderr, "size %d\n", size);
+        for (i = 0; i < num_chars - 1; i++)
+          putc('-', stderr);
+        fprintf(stderr, "\n\n");
 
         ta_glyph_hints_dump_edges(_ta_debug_hints);
         ta_glyph_hints_dump_segments(_ta_debug_hints);
         ta_glyph_hints_dump_points(_ta_debug_hints);
 
-        fprintf(stderr, "  action hints record:\n");
-        for (p = ins_buf; p < recorder.hints_record.buf; p += 2)
-          fprintf(stderr, " %2d", *p * 256 + *(p + 1));
+        fprintf(stderr, "action hints record:\n");
+        if (ins_buf == recorder.hints_record.buf)
+          fprintf(stderr, "  (none)");
+        else
+        {
+          fprintf(stderr, "  ");
+          for (p = ins_buf; p < recorder.hints_record.buf; p += 2)
+            fprintf(stderr, " %2d", *p * 256 + *(p + 1));
+        }
         fprintf(stderr, "\n");
       }
 #endif
@@ -1838,20 +1869,33 @@ TA_sfnt_build_glyph_instructions(SFNT* sfnt,
                                      ins_buf, recorder.hints_record.buf))
     {
 #ifdef DEBUGGING
+      if (font->debug)
       {
         if (!have_dumps)
         {
-          fprintf(stderr, "  size %d:\n", size);
+          int num_chars, i;
+
+
+          num_chars = fprintf(stderr, "size %d\n", size);
+          for (i = 0; i < num_chars - 1; i++)
+            putc('-', stderr);
+          fprintf(stderr, "\n\n");
 
           ta_glyph_hints_dump_edges(_ta_debug_hints);
           ta_glyph_hints_dump_segments(_ta_debug_hints);
           ta_glyph_hints_dump_points(_ta_debug_hints);
         }
 
-        fprintf(stderr, "  point hints record:\n");
-        for (p = ins_buf; p < recorder.hints_record.buf; p += 2)
-          fprintf(stderr, " %2d", *p * 256 + *(p + 1));
-        fprintf(stderr, "\n");
+        fprintf(stderr, "point hints record:\n");
+        if (ins_buf == recorder.hints_record.buf)
+          fprintf(stderr, "  (none)");
+        else
+        {
+          fprintf(stderr, "  ");
+          for (p = ins_buf; p < recorder.hints_record.buf; p += 2)
+            fprintf(stderr, " %2d", *p * 256 + *(p + 1));
+        }
+        fprintf(stderr, "\n\n");
       }
 #endif
 
@@ -2024,6 +2068,7 @@ Done2:
 
 Done:
   TA_free_hints_records(action_hints_records, num_action_hints_records);
+  TA_free_hints_records(point_hints_records, num_point_hints_records);
   TA_free_recorder(&recorder);
 
   /* we are done, so reallocate the instruction array to its real size */
@@ -2054,6 +2099,7 @@ Done1:
 
 Err:
   TA_free_hints_records(action_hints_records, num_action_hints_records);
+  TA_free_hints_records(point_hints_records, num_point_hints_records);
   TA_free_recorder(&recorder);
   free(ins_buf);
 
