@@ -296,11 +296,12 @@
 
 #define sal_i 0
 #define sal_j sal_i + 1
-#define sal_k sal_j + 1
-#define sal_temp1 sal_k + 1
+#define sal_temp1 sal_j + 1
 #define sal_temp2 sal_temp1 + 1
 #define sal_temp3 sal_temp2 + 1
-#define sal_limit sal_temp3 + 1
+#define sal_best sal_temp3 + 1
+#define sal_ref sal_best + 1
+#define sal_limit sal_ref + 1
 #define sal_func sal_limit +1
 #define sal_anchor sal_func + 1
 #define sal_point_min sal_anchor + 1
@@ -314,19 +315,21 @@
 
 /* 0 */
 #define bci_round 0
-#define bci_compute_stem_width bci_round + 1
-#define bci_loop bci_compute_stem_width + 1
+#define bci_smooth_stem_width bci_round + 1
+#define bci_get_best_width bci_smooth_stem_width + 1
+#define bci_strong_stem_width bci_get_best_width + 1
+#define bci_loop bci_strong_stem_width + 1
 #define bci_cvt_rescale bci_loop + 1
 #define bci_blue_round bci_cvt_rescale + 1
 #define bci_decrement_component_counter bci_blue_round + 1
 #define bci_get_point_extrema bci_decrement_component_counter + 1
 #define bci_nibbles bci_get_point_extrema + 1
 
-/* 8 */
+/* 10 */
 #define bci_create_segment bci_nibbles + 1
 #define bci_create_segments bci_create_segment + 1
 
-/* 10 */
+/* 12 */
 /* the next ten entries must stay in this order */
 #define bci_create_segments_0 bci_create_segments + 1
 #define bci_create_segments_1 bci_create_segments_0 + 1
@@ -341,7 +344,7 @@
 
 #define bci_create_segments_composite bci_create_segments_9 + 1
 
-/* 21 */
+/* 23 */
 /* the next ten entries must stay in this order */
 #define bci_create_segments_composite_0 bci_create_segments_composite + 1
 #define bci_create_segments_composite_1 bci_create_segments_composite_0 + 1
@@ -354,24 +357,24 @@
 #define bci_create_segments_composite_8 bci_create_segments_composite_7 + 1
 #define bci_create_segments_composite_9 bci_create_segments_composite_8 + 1
 
-/* 31 */
+/* 33 */
 #define bci_align_segment bci_create_segments_composite_9 + 1
 #define bci_align_segments bci_align_segment + 1
 
-/* 33 */
+/* 35 */
 #define bci_scale_contour bci_align_segments + 1
 #define bci_scale_glyph bci_scale_contour + 1
 #define bci_scale_composite_glyph bci_scale_glyph + 1
 #define bci_shift_contour bci_scale_composite_glyph + 1
 #define bci_shift_subglyph bci_shift_contour + 1
 
-/* 38 */
+/* 40 */
 #define bci_ip_outer_align_point bci_shift_subglyph + 1
 #define bci_ip_on_align_points bci_ip_outer_align_point + 1
 #define bci_ip_between_align_point bci_ip_on_align_points + 1
 #define bci_ip_between_align_points bci_ip_between_align_point + 1
 
-/* 42 */
+/* 44 */
 #define bci_adjust_common bci_ip_between_align_points + 1
 #define bci_stem_common bci_adjust_common + 1
 #define bci_serif_common bci_stem_common + 1
@@ -379,12 +382,12 @@
 #define bci_serif_link1_common bci_serif_anchor_common + 1
 #define bci_serif_link2_common bci_serif_link1_common + 1
 
-/* 48 */
+/* 50 */
 #define bci_lower_bound bci_serif_link2_common + 1
 #define bci_upper_bound bci_lower_bound + 1
 #define bci_upper_lower_bound bci_upper_bound + 1
 
-/* 51 */
+/* 53 */
 #define bci_adjust_bound bci_upper_lower_bound + 1
 #define bci_stem_bound bci_adjust_bound + 1
 #define bci_link bci_stem_bound + 1
@@ -395,23 +398,23 @@
 /* the order of the `bci_action_*' entries must correspond */
 /* to the order of the TA_Action enumeration entries (in `tahints.h') */
 
-/* 57 */
+/* 59 */
 #define bci_action_ip_before bci_stem + 1
 #define bci_action_ip_after bci_action_ip_before + 1
 #define bci_action_ip_on bci_action_ip_after + 1
 #define bci_action_ip_between bci_action_ip_on + 1
 
-/* 61 */
+/* 63 */
 #define bci_action_blue bci_action_ip_between + 1
 #define bci_action_blue_anchor bci_action_blue + 1
 
-/* 63 */
+/* 67 */
 #define bci_action_anchor bci_action_blue_anchor + 1
 #define bci_action_anchor_serif bci_action_anchor + 1
 #define bci_action_anchor_round bci_action_anchor_serif + 1
 #define bci_action_anchor_round_serif bci_action_anchor_round + 1
 
-/* 67 */
+/* 69 */
 #define bci_action_adjust bci_action_anchor_round_serif + 1
 #define bci_action_adjust_serif bci_action_adjust + 1
 #define bci_action_adjust_round bci_action_adjust_serif + 1
@@ -421,13 +424,13 @@
 #define bci_action_adjust_bound_round bci_action_adjust_bound_serif + 1
 #define bci_action_adjust_bound_round_serif bci_action_adjust_bound_round + 1
 
-/* 75 */
+/* 77 */
 #define bci_action_link bci_action_adjust_bound_round_serif + 1
 #define bci_action_link_serif bci_action_link + 1
 #define bci_action_link_round bci_action_link_serif + 1
 #define bci_action_link_round_serif bci_action_link_round + 1
 
-/* 79 */
+/* 81 */
 #define bci_action_stem bci_action_link_round_serif + 1
 #define bci_action_stem_serif bci_action_stem + 1
 #define bci_action_stem_round bci_action_stem_serif + 1
@@ -437,31 +440,31 @@
 #define bci_action_stem_bound_round bci_action_stem_bound_serif + 1
 #define bci_action_stem_bound_round_serif bci_action_stem_bound_round + 1
 
-/* 87 */
+/* 89 */
 #define bci_action_serif bci_action_stem_bound_round_serif + 1
 #define bci_action_serif_lower_bound bci_action_serif + 1
 #define bci_action_serif_upper_bound bci_action_serif_lower_bound + 1
 #define bci_action_serif_upper_lower_bound bci_action_serif_upper_bound + 1
 
-/* 91 */
+/* 93 */
 #define bci_action_serif_anchor bci_action_serif_upper_lower_bound + 1
 #define bci_action_serif_anchor_lower_bound bci_action_serif_anchor + 1
 #define bci_action_serif_anchor_upper_bound bci_action_serif_anchor_lower_bound + 1
 #define bci_action_serif_anchor_upper_lower_bound bci_action_serif_anchor_upper_bound + 1
 
-/* 95 */
+/* 97 */
 #define bci_action_serif_link1 bci_action_serif_anchor_upper_lower_bound + 1
 #define bci_action_serif_link1_lower_bound bci_action_serif_link1 + 1
 #define bci_action_serif_link1_upper_bound bci_action_serif_link1_lower_bound + 1
 #define bci_action_serif_link1_upper_lower_bound bci_action_serif_link1_upper_bound + 1
 
-/* 99 */
+/* 101 */
 #define bci_action_serif_link2 bci_action_serif_link1_upper_lower_bound + 1
 #define bci_action_serif_link2_lower_bound bci_action_serif_link2 + 1
 #define bci_action_serif_link2_upper_bound bci_action_serif_link2_lower_bound + 1
 #define bci_action_serif_link2_upper_lower_bound bci_action_serif_link2_upper_bound + 1
 
-/* 103 */
+/* 105 */
 #define bci_hint_glyph bci_action_serif_link2_upper_lower_bound + 1
 
 #define NUM_FDEFS bci_hint_glyph + 1 /* must be last */
@@ -479,7 +482,8 @@
 #define cvtl_funits_to_pixels cvtl_scale + 1
 #define cvtl_is_extra_light cvtl_funits_to_pixels + 1
 #define cvtl_is_subglyph cvtl_is_extra_light + 1
-#define cvtl_max_runtime cvtl_is_subglyph + 1 /* must be last */
+#define cvtl_stem_width_function cvtl_is_subglyph + 1
+#define cvtl_max_runtime cvtl_stem_width_function + 1 /* must be last */
 
 /* symbolic names for compile-time CVT locations */
 /* (assigned in `cvt') */
